@@ -63,7 +63,7 @@ class Diff2HTMLTransform(Transform):
                     '+': 'diffNewLine',
                     ' ': 'diffLine'}[line[0]]
         if line.strip():
-            w(u'<div class="%s">%s</div>\n' % (cssclass, xml_escape(line)))
+            w(u'<span class="%s">%s</span>\n' % (cssclass, xml_escape(line)))
 
     def comment_line(self, trdata, w, line):
         w(xml_escape(line) + '<br/>')
