@@ -40,16 +40,13 @@ class LinkOrCreatePatchOp(hook.DataOperationMixIn, hook.Operation):
                 patch = entity.vc_rename[0].patch
             else:
                 # search for previous revision of the patch file
-                branches = set(x.branch for x in entity.rev.parent_revision)
-                for branch in branches:
-                    parent = entity.previous_version(branch)
-                    if parent is not None:
-                        if (entity.__regid__ == 'DeletedVersionContent' and
-                            getattr(parent, 'reverse_vc_rename', None)):
-                            return # skip file deleted because of renaming
-                        if parent.patch:
-                            patch = parent.patch
-                            break
+                for parent in entity.previous_versions():
+                    if (entity.__regid__ == 'DeletedVersionContent' and
+                        getattr(parent, 'reverse_vc_rename', None)):
+                        return # skip file deleted because of renaming
+                    if parent.patch:
+                        patch = parent.patch
+                        break
             # create a new patch entity if no one found or if found a closed
             # patch and this is not a file deletion
             if patch is None or (not patch.is_active() and entity.__regid__ == 'VersionContent'):
